'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def describe_stream(StreamArn=None, Limit=None, ExclusiveStartShardId=None):
    """
    Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.
    Each shard in the stream has a SequenceNumberRange associated with it. If the SequenceNumberRange has a StartingSequenceNumber but no EndingSequenceNumber , then the shard is still open (able to receive more stream records). If both StartingSequenceNumber and EndingSequenceNumber are present, then that shard is closed and can no longer receive more data.
    See also: AWS API Documentation
    
    Examples
    The following example describes a stream with a given stream ARN.
    Expected Output:
    
    :example: response = client.describe_stream(
        StreamArn='string',
        Limit=123,
        ExclusiveStartShardId='string'
    )
    
    
    :type StreamArn: string
    :param StreamArn: [REQUIRED]
            The Amazon Resource Name (ARN) for the stream.
            

    :type Limit: integer
    :param Limit: The maximum number of shard objects to return. The upper limit is 100.

    :type ExclusiveStartShardId: string
    :param ExclusiveStartShardId: The shard ID of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedShardId in the previous operation.

    :rtype: dict
    :return: {
        'StreamDescription': {
            'StreamArn': 'string',
            'StreamLabel': 'string',
            'StreamStatus': 'ENABLING'|'ENABLED'|'DISABLING'|'DISABLED',
            'StreamViewType': 'NEW_IMAGE'|'OLD_IMAGE'|'NEW_AND_OLD_IMAGES'|'KEYS_ONLY',
            'CreationRequestDateTime': datetime(2015, 1, 1),
            'TableName': 'string',
            'KeySchema': [
                {
                    'AttributeName': 'string',
                    'KeyType': 'HASH'|'RANGE'
                },
            ],
            'Shards': [
                {
                    'ShardId': 'string',
                    'SequenceNumberRange': {
                        'StartingSequenceNumber': 'string',
                        'EndingSequenceNumber': 'string'
                    },
                    'ParentShardId': 'string'
                },
            ],
            'LastEvaluatedShardId': 'string'
        }
    }
    
    
    :returns: 
    the AWS customer ID.
    the table name
    the StreamLabel
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_records(ShardIterator=None, Limit=None):
    """
    Retrieves the stream records from a given shard.
    Specify a shard iterator using the ShardIterator parameter. The shard iterator specifies the position in the shard from which you want to start reading stream records sequentially. If there are no stream records available in the portion of the shard that the iterator points to, GetRecords returns an empty list. Note that it might take multiple calls to get to a portion of the shard that contains stream records.
    See also: AWS API Documentation
    
    Examples
    The following example retrieves all the stream records from a shard.
    Expected Output:
    
    :example: response = client.get_records(
        ShardIterator='string',
        Limit=123
    )
    
    
    :type ShardIterator: string
    :param ShardIterator: [REQUIRED]
            A shard iterator that was retrieved from a previous GetShardIterator operation. This iterator can be used to access the stream records in this shard.
            

    :type Limit: integer
    :param Limit: The maximum number of records to return from the shard. The upper limit is 1000.

    :rtype: dict
    :return: {
        'Records': [
            {
                'eventID': 'string',
                'eventName': 'INSERT'|'MODIFY'|'REMOVE',
                'eventVersion': 'string',
                'eventSource': 'string',
                'awsRegion': 'string',
                'dynamodb': {
                    'ApproximateCreationDateTime': datetime(2015, 1, 1),
                    'Keys': {
                        'string': {
                            'S': 'string',
                            'N': 'string',
                            'B': b'bytes',
                            'SS': [
                                'string',
                            ],
                            'NS': [
                                'string',
                            ],
                            'BS': [
                                b'bytes',
                            ],
                            'M': {
                                'string': {'... recursive ...'}
                            },
                            'L': [
                                {'... recursive ...'},
                            ],
                            'NULL': True|False,
                            'BOOL': True|False
                        }
                    },
                    'NewImage': {
                        'string': {
                            'S': 'string',
                            'N': 'string',
                            'B': b'bytes',
                            'SS': [
                                'string',
                            ],
                            'NS': [
                                'string',
                            ],
                            'BS': [
                                b'bytes',
                            ],
                            'M': {
                                'string': {'... recursive ...'}
                            },
                            'L': [
                                {'... recursive ...'},
                            ],
                            'NULL': True|False,
                            'BOOL': True|False
                        }
                    },
                    'OldImage': {
                        'string': {
                            'S': 'string',
                            'N': 'string',
                            'B': b'bytes',
                            'SS': [
                                'string',
                            ],
                            'NS': [
                                'string',
                            ],
                            'BS': [
                                b'bytes',
                            ],
                            'M': {
                                'string': {'... recursive ...'}
                            },
                            'L': [
                                {'... recursive ...'},
                            ],
                            'NULL': True|False,
                            'BOOL': True|False
                        }
                    },
                    'SequenceNumber': 'string',
                    'SizeBytes': 123,
                    'StreamViewType': 'NEW_IMAGE'|'OLD_IMAGE'|'NEW_AND_OLD_IMAGES'|'KEYS_ONLY'
                },
                'userIdentity': {
                    'PrincipalId': 'string',
                    'Type': 'string'
                }
            },
        ],
        'NextShardIterator': 'string'
    }
    
    
    :returns: 
    INSERT - a new item was added to the table.
    MODIFY - one or more of an existing item's attributes were modified.
    REMOVE - the item was deleted from the table
    
    """
    pass

def get_shard_iterator(StreamArn=None, ShardId=None, ShardIteratorType=None, SequenceNumber=None):
    """
    Returns a shard iterator. A shard iterator provides information about how to retrieve the stream records from within a shard. Use the shard iterator in a subsequent GetRecords request to read the stream records from the shard.
    See also: AWS API Documentation
    
    Examples
    The following example returns a shard iterator for the provided stream ARN and shard ID.
    Expected Output:
    
    :example: response = client.get_shard_iterator(
        StreamArn='string',
        ShardId='string',
        ShardIteratorType='TRIM_HORIZON'|'LATEST'|'AT_SEQUENCE_NUMBER'|'AFTER_SEQUENCE_NUMBER',
        SequenceNumber='string'
    )
    
    
    :type StreamArn: string
    :param StreamArn: [REQUIRED]
            The Amazon Resource Name (ARN) for the stream.
            

    :type ShardId: string
    :param ShardId: [REQUIRED]
            The identifier of the shard. The iterator will be returned for this shard ID.
            

    :type ShardIteratorType: string
    :param ShardIteratorType: [REQUIRED]
            Determines how the shard iterator is used to start reading stream records from the shard:
            AT_SEQUENCE_NUMBER - Start reading exactly from the position denoted by a specific sequence number.
            AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number.
            TRIM_HORIZON - Start reading at the last (untrimmed) stream record, which is the oldest record in the shard. In DynamoDB Streams, there is a 24 hour limit on data retention. Stream records whose age exceeds this limit are subject to removal (trimming) from the stream.
            LATEST - Start reading just after the most recent stream record in the shard, so that you always read the most recent data in the shard.
            

    :type SequenceNumber: string
    :param SequenceNumber: The sequence number of a stream record in the shard from which to start reading.

    :rtype: dict
    :return: {
        'ShardIterator': 'string'
    }
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_streams(TableName=None, Limit=None, ExclusiveStartStreamArn=None):
    """
    Returns an array of stream ARNs associated with the current account and endpoint. If the TableName parameter is present, then ListStreams will return only the streams ARNs for that table.
    See also: AWS API Documentation
    
    Examples
    The following example lists all of the stream ARNs.
    Expected Output:
    
    :example: response = client.list_streams(
        TableName='string',
        Limit=123,
        ExclusiveStartStreamArn='string'
    )
    
    
    :type TableName: string
    :param TableName: If this parameter is provided, then only the streams associated with this table name are returned.

    :type Limit: integer
    :param Limit: The maximum number of streams to return. The upper limit is 100.

    :type ExclusiveStartStreamArn: string
    :param ExclusiveStartStreamArn: The ARN (Amazon Resource Name) of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedStreamArn in the previous operation.

    :rtype: dict
    :return: {
        'Streams': [
            {
                'StreamArn': 'string',
                'TableName': 'string',
                'StreamLabel': 'string'
            },
        ],
        'LastEvaluatedStreamArn': 'string'
    }
    
    
    :returns: 
    the AWS customer ID.
    the table name
    the StreamLabel
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def delete_report_definition(ReportName=None):
    """
    Delete a specified report definition
    See also: AWS API Documentation
    
    
    :example: response = client.delete_report_definition(
        ReportName='string'
    )
    
    
    :type ReportName: string
    :param ReportName: Preferred name for a report, it has to be unique. Must starts with a number/letter, case sensitive. Limited to 256 characters.

    :rtype: dict
    :return: {
        'ResponseMessage': 'string'
    }
    
    
    """
    pass

def describe_report_definitions(MaxResults=None, NextToken=None):
    """
    Describe a list of report definitions owned by the account
    See also: AWS API Documentation
    
    
    :example: response = client.describe_report_definitions(
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: The max number of results returned by the operation.

    :type NextToken: string
    :param NextToken: A generic string.

    :rtype: dict
    :return: {
        'ReportDefinitions': [
            {
                'ReportName': 'string',
                'TimeUnit': 'HOURLY'|'DAILY',
                'Format': 'textORcsv',
                'Compression': 'ZIP'|'GZIP',
                'AdditionalSchemaElements': [
                    'RESOURCES',
                ],
                'S3Bucket': 'string',
                'S3Prefix': 'string',
                'S3Region': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-central-1'|'eu-west-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1',
                'AdditionalArtifacts': [
                    'REDSHIFT'|'QUICKSIGHT',
                ]
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (dict) -- Response of DescribeReportDefinitions
    ReportDefinitions (list) -- A list of report definitions.
    (dict) -- The definition of AWS Cost and Usage Report. Customer can specify the report name, time unit, report format, compression format, S3 bucket and additional artifacts and schema elements in the definition.
    ReportName (string) -- Preferred name for a report, it has to be unique. Must starts with a number/letter, case sensitive. Limited to 256 characters.
    TimeUnit (string) -- The frequency on which report data are measured and displayed.
    Format (string) -- Preferred format for report.
    Compression (string) -- Preferred compression format for report.
    AdditionalSchemaElements (list) -- A list of schema elements.
    (string) -- Preference of including Resource IDs. You can include additional details about individual resource IDs in your report.
    
    
    S3Bucket (string) -- Name of customer S3 bucket.
    S3Prefix (string) -- Preferred report path prefix. Limited to 256 characters.
    S3Region (string) -- Region of customer S3 bucket.
    AdditionalArtifacts (list) -- A list of additional artifacts.
    (string) -- Enable support for Redshift and/or QuickSight.
    
    
    
    
    
    
    NextToken (string) -- A generic string.
    
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def put_report_definition(ReportDefinition=None):
    """
    Create a new report definition
    See also: AWS API Documentation
    
    
    :example: response = client.put_report_definition(
        ReportDefinition={
            'ReportName': 'string',
            'TimeUnit': 'HOURLY'|'DAILY',
            'Format': 'textORcsv',
            'Compression': 'ZIP'|'GZIP',
            'AdditionalSchemaElements': [
                'RESOURCES',
            ],
            'S3Bucket': 'string',
            'S3Prefix': 'string',
            'S3Region': 'us-east-1'|'us-west-1'|'us-west-2'|'eu-central-1'|'eu-west-1'|'ap-southeast-1'|'ap-southeast-2'|'ap-northeast-1',
            'AdditionalArtifacts': [
                'REDSHIFT'|'QUICKSIGHT',
            ]
        }
    )
    
    
    :type ReportDefinition: dict
    :param ReportDefinition: [REQUIRED] The definition of AWS Cost and Usage Report. Customer can specify the report name, time unit, report format, compression format, S3 bucket and additional artifacts and schema elements in the definition.
            ReportName (string) -- [REQUIRED] Preferred name for a report, it has to be unique. Must starts with a number/letter, case sensitive. Limited to 256 characters.
            TimeUnit (string) -- [REQUIRED] The frequency on which report data are measured and displayed.
            Format (string) -- [REQUIRED] Preferred format for report.
            Compression (string) -- [REQUIRED] Preferred compression format for report.
            AdditionalSchemaElements (list) -- [REQUIRED] A list of schema elements.
            (string) -- Preference of including Resource IDs. You can include additional details about individual resource IDs in your report.
            S3Bucket (string) -- [REQUIRED] Name of customer S3 bucket.
            S3Prefix (string) -- [REQUIRED] Preferred report path prefix. Limited to 256 characters.
            S3Region (string) -- [REQUIRED] Region of customer S3 bucket.
            AdditionalArtifacts (list) -- A list of additional artifacts.
            (string) -- Enable support for Redshift and/or QuickSight.
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) -- Response of PutReportDefinition
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def associate_fleet(FleetName=None, StackName=None):
    """
    Associate a fleet to a stack.
    See also: AWS API Documentation
    
    
    :example: response = client.associate_fleet(
        FleetName='string',
        StackName='string'
    )
    
    
    :type FleetName: string
    :param FleetName: [REQUIRED]
            The name of the fleet to associate.
            

    :type StackName: string
    :param StackName: [REQUIRED]
            The name of the stack to which the fleet is associated.
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_fleet(Name=None, ImageName=None, InstanceType=None, ComputeCapacity=None, VpcConfig=None, MaxUserDurationInSeconds=None, DisconnectTimeoutInSeconds=None, Description=None, DisplayName=None, EnableDefaultInternetAccess=None):
    """
    Creates a new fleet.
    See also: AWS API Documentation
    
    
    :example: response = client.create_fleet(
        Name='string',
        ImageName='string',
        InstanceType='string',
        ComputeCapacity={
            'DesiredInstances': 123
        },
        VpcConfig={
            'SubnetIds': [
                'string',
            ]
        },
        MaxUserDurationInSeconds=123,
        DisconnectTimeoutInSeconds=123,
        Description='string',
        DisplayName='string',
        EnableDefaultInternetAccess=True|False
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            A unique identifier for the fleet.
            

    :type ImageName: string
    :param ImageName: [REQUIRED]
            Unique name of the image used by the fleet.
            

    :type InstanceType: string
    :param InstanceType: [REQUIRED]
            The instance type of compute resources for the fleet. Fleet instances are launched from this instance type.
            

    :type ComputeCapacity: dict
    :param ComputeCapacity: [REQUIRED]
            The parameters for the capacity allocated to the fleet.
            DesiredInstances (integer) -- [REQUIRED]The desired number of streaming instances.
            

    :type VpcConfig: dict
    :param VpcConfig: The VPC configuration for the fleet.
            SubnetIds (list) --The list of subnets to which a network interface is established from the fleet instance.
            (string) --
            

    :type MaxUserDurationInSeconds: integer
    :param MaxUserDurationInSeconds: The maximum time for which a streaming session can run. The input can be any numeric value in seconds between 600 and 57600.

    :type DisconnectTimeoutInSeconds: integer
    :param DisconnectTimeoutInSeconds: The time after disconnection when a session is considered to have ended. If a user who got disconnected reconnects within this timeout interval, the user is connected back to their previous session. The input can be any numeric value in seconds between 60 and 57600.

    :type Description: string
    :param Description: The description of the fleet.

    :type DisplayName: string
    :param DisplayName: The display name of the fleet.

    :type EnableDefaultInternetAccess: boolean
    :param EnableDefaultInternetAccess: Enables or disables default Internet access for the fleet.

    :rtype: dict
    :return: {
        'Fleet': {
            'Arn': 'string',
            'Name': 'string',
            'DisplayName': 'string',
            'Description': 'string',
            'ImageName': 'string',
            'InstanceType': 'string',
            'ComputeCapacityStatus': {
                'Desired': 123,
                'Running': 123,
                'InUse': 123,
                'Available': 123
            },
            'MaxUserDurationInSeconds': 123,
            'DisconnectTimeoutInSeconds': 123,
            'State': 'STARTING'|'RUNNING'|'STOPPING'|'STOPPED',
            'VpcConfig': {
                'SubnetIds': [
                    'string',
                ]
            },
            'CreatedTime': datetime(2015, 1, 1),
            'FleetErrors': [
                {
                    'ErrorCode': 'IAM_SERVICE_ROLE_MISSING_ENI_DESCRIBE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_CREATE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_DELETE_ACTION'|'NETWORK_INTERFACE_LIMIT_EXCEEDED'|'INTERNAL_SERVICE_ERROR'|'IAM_SERVICE_ROLE_IS_MISSING'|'SUBNET_HAS_INSUFFICIENT_IP_ADDRESSES'|'IAM_SERVICE_ROLE_MISSING_DESCRIBE_SUBNET_ACTION'|'SUBNET_NOT_FOUND'|'IMAGE_NOT_FOUND'|'INVALID_SUBNET_CONFIGURATION',
                    'ErrorMessage': 'string'
                },
            ],
            'EnableDefaultInternetAccess': True|False
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def create_stack(Name=None, Description=None, DisplayName=None, StorageConnectors=None):
    """
    Create a new stack.
    See also: AWS API Documentation
    
    
    :example: response = client.create_stack(
        Name='string',
        Description='string',
        DisplayName='string',
        StorageConnectors=[
            {
                'ConnectorType': 'HOMEFOLDERS',
                'ResourceIdentifier': 'string'
            },
        ]
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            The unique identifier for this stack.
            

    :type Description: string
    :param Description: The description displayed to end users on the AppStream 2.0 portal.

    :type DisplayName: string
    :param DisplayName: The name displayed to end users on the AppStream 2.0 portal.

    :type StorageConnectors: list
    :param StorageConnectors: The storage connectors to be enabled for the stack.
            (dict) --Contains the parameters for a storage connector.
            ConnectorType (string) -- [REQUIRED]The type of storage connector. The possible values include: HOMEFOLDERS.
            ResourceIdentifier (string) --The ARN associated with the storage connector.
            
            

    :rtype: dict
    :return: {
        'Stack': {
            'Arn': 'string',
            'Name': 'string',
            'Description': 'string',
            'DisplayName': 'string',
            'CreatedTime': datetime(2015, 1, 1),
            'StorageConnectors': [
                {
                    'ConnectorType': 'HOMEFOLDERS',
                    'ResourceIdentifier': 'string'
                },
            ],
            'StackErrors': [
                {
                    'ErrorCode': 'STORAGE_CONNECTOR_ERROR'|'INTERNAL_SERVICE_ERROR',
                    'ErrorMessage': 'string'
                },
            ]
        }
    }
    
    
    """
    pass

def create_streaming_url(StackName=None, FleetName=None, UserId=None, ApplicationId=None, Validity=None, SessionContext=None):
    """
    Creates a URL to start an AppStream 2.0 streaming session for a user. By default, the URL is valid only for 1 minute from the time that it is generated.
    See also: AWS API Documentation
    
    
    :example: response = client.create_streaming_url(
        StackName='string',
        FleetName='string',
        UserId='string',
        ApplicationId='string',
        Validity=123,
        SessionContext='string'
    )
    
    
    :type StackName: string
    :param StackName: [REQUIRED]
            The stack for which the URL is generated.
            

    :type FleetName: string
    :param FleetName: [REQUIRED]
            The fleet for which the URL is generated.
            

    :type UserId: string
    :param UserId: [REQUIRED]
            A unique user ID for whom the URL is generated.
            

    :type ApplicationId: string
    :param ApplicationId: The ID of the application that must be launched after the session starts.

    :type Validity: integer
    :param Validity: The duration up to which the URL returned by this action is valid. The input can be any numeric value in seconds between 1 and 604800 seconds.

    :type SessionContext: string
    :param SessionContext: The sessionContext of the streaming URL.

    :rtype: dict
    :return: {
        'StreamingURL': 'string',
        'Expires': datetime(2015, 1, 1)
    }
    
    
    """
    pass

def delete_fleet(Name=None):
    """
    Deletes a fleet.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_fleet(
        Name='string'
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            The name of the fleet to be deleted.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def delete_stack(Name=None):
    """
    Deletes the stack. After this operation completes, the environment can no longer be activated, and any reservations made for the stack are released.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_stack(
        Name='string'
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            The name of the stack to delete.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def describe_fleets(Names=None, NextToken=None):
    """
    If fleet names are provided, this operation describes the specified fleets; otherwise, all the fleets in the account are described.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_fleets(
        Names=[
            'string',
        ],
        NextToken='string'
    )
    
    
    :type Names: list
    :param Names: The fleet names to describe. Use null to describe all the fleets for the AWS account.
            (string) --
            

    :type NextToken: string
    :param NextToken: The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

    :rtype: dict
    :return: {
        'Fleets': [
            {
                'Arn': 'string',
                'Name': 'string',
                'DisplayName': 'string',
                'Description': 'string',
                'ImageName': 'string',
                'InstanceType': 'string',
                'ComputeCapacityStatus': {
                    'Desired': 123,
                    'Running': 123,
                    'InUse': 123,
                    'Available': 123
                },
                'MaxUserDurationInSeconds': 123,
                'DisconnectTimeoutInSeconds': 123,
                'State': 'STARTING'|'RUNNING'|'STOPPING'|'STOPPED',
                'VpcConfig': {
                    'SubnetIds': [
                        'string',
                    ]
                },
                'CreatedTime': datetime(2015, 1, 1),
                'FleetErrors': [
                    {
                        'ErrorCode': 'IAM_SERVICE_ROLE_MISSING_ENI_DESCRIBE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_CREATE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_DELETE_ACTION'|'NETWORK_INTERFACE_LIMIT_EXCEEDED'|'INTERNAL_SERVICE_ERROR'|'IAM_SERVICE_ROLE_IS_MISSING'|'SUBNET_HAS_INSUFFICIENT_IP_ADDRESSES'|'IAM_SERVICE_ROLE_MISSING_DESCRIBE_SUBNET_ACTION'|'SUBNET_NOT_FOUND'|'IMAGE_NOT_FOUND'|'INVALID_SUBNET_CONFIGURATION',
                        'ErrorMessage': 'string'
                    },
                ],
                'EnableDefaultInternetAccess': True|False
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_images(Names=None):
    """
    Describes the images. If a list of names is not provided, all images in your account are returned. This operation does not return a paginated result.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_images(
        Names=[
            'string',
        ]
    )
    
    
    :type Names: list
    :param Names: A specific list of images to describe.
            (string) --
            

    :rtype: dict
    :return: {
        'Images': [
            {
                'Name': 'string',
                'Arn': 'string',
                'BaseImageArn': 'string',
                'DisplayName': 'string',
                'State': 'PENDING'|'AVAILABLE'|'FAILED'|'DELETING',
                'Visibility': 'PUBLIC'|'PRIVATE',
                'ImageBuilderSupported': True|False,
                'Platform': 'WINDOWS',
                'Description': 'string',
                'StateChangeReason': {
                    'Code': 'INTERNAL_ERROR'|'IMAGE_BUILDER_NOT_AVAILABLE',
                    'Message': 'string'
                },
                'Applications': [
                    {
                        'Name': 'string',
                        'DisplayName': 'string',
                        'IconURL': 'string',
                        'LaunchPath': 'string',
                        'LaunchParameters': 'string',
                        'Enabled': True|False,
                        'Metadata': {
                            'string': 'string'
                        }
                    },
                ],
                'CreatedTime': datetime(2015, 1, 1),
                'PublicBaseImageReleasedDate': datetime(2015, 1, 1)
            },
        ]
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def describe_sessions(StackName=None, FleetName=None, UserId=None, NextToken=None, Limit=None, AuthenticationType=None):
    """
    Describes the streaming sessions for a stack and a fleet. If a user ID is provided, this operation returns streaming sessions for only that user. Pass this value for the nextToken parameter in a subsequent call to this operation to retrieve the next set of items. If an authentication type is not provided, the operation defaults to users authenticated using a streaming URL.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_sessions(
        StackName='string',
        FleetName='string',
        UserId='string',
        NextToken='string',
        Limit=123,
        AuthenticationType='API'|'SAML'
    )
    
    
    :type StackName: string
    :param StackName: [REQUIRED]
            The name of the stack for which to list sessions.
            

    :type FleetName: string
    :param FleetName: [REQUIRED]
            The name of the fleet for which to list sessions.
            

    :type UserId: string
    :param UserId: The user for whom to list sessions. Use null to describe all the sessions for the stack and fleet.

    :type NextToken: string
    :param NextToken: The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

    :type Limit: integer
    :param Limit: The size of each page of results. The default value is 20 and the maximum supported value is 50.

    :type AuthenticationType: string
    :param AuthenticationType: The authentication method of the user. It can be API for a user authenticated using a streaming URL, or SAML for a SAML federated user. If an authentication type is not provided, the operation defaults to users authenticated using a streaming URL.

    :rtype: dict
    :return: {
        'Sessions': [
            {
                'Id': 'string',
                'UserId': 'string',
                'StackName': 'string',
                'FleetName': 'string',
                'State': 'ACTIVE'|'PENDING'|'EXPIRED',
                'AuthenticationType': 'API'|'SAML'
            },
        ],
        'NextToken': 'string'
    }
    
    
    """
    pass

def describe_stacks(Names=None, NextToken=None):
    """
    If stack names are not provided, this operation describes the specified stacks; otherwise, all stacks in the account are described. Pass the nextToken value in a subsequent call to this operation to retrieve the next set of items.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_stacks(
        Names=[
            'string',
        ],
        NextToken='string'
    )
    
    
    :type Names: list
    :param Names: The stack names to describe. Use null to describe all the stacks for the AWS account.
            (string) --
            

    :type NextToken: string
    :param NextToken: The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

    :rtype: dict
    :return: {
        'Stacks': [
            {
                'Arn': 'string',
                'Name': 'string',
                'Description': 'string',
                'DisplayName': 'string',
                'CreatedTime': datetime(2015, 1, 1),
                'StorageConnectors': [
                    {
                        'ConnectorType': 'HOMEFOLDERS',
                        'ResourceIdentifier': 'string'
                    },
                ],
                'StackErrors': [
                    {
                        'ErrorCode': 'STORAGE_CONNECTOR_ERROR'|'INTERNAL_SERVICE_ERROR',
                        'ErrorMessage': 'string'
                    },
                ]
            },
        ],
        'NextToken': 'string'
    }
    
    
    """
    pass

def disassociate_fleet(FleetName=None, StackName=None):
    """
    Disassociates a fleet from a stack.
    See also: AWS API Documentation
    
    
    :example: response = client.disassociate_fleet(
        FleetName='string',
        StackName='string'
    )
    
    
    :type FleetName: string
    :param FleetName: [REQUIRED]
            The name of the fleet to disassociate.
            

    :type StackName: string
    :param StackName: [REQUIRED]
            The name of the stack with which the fleet is associated.
            

    :rtype: dict
    :return: {}
    
    
    :returns: 
    (dict) --
    
    """
    pass

def expire_session(SessionId=None):
    """
    This operation immediately stops a streaming session.
    See also: AWS API Documentation
    
    
    :example: response = client.expire_session(
        SessionId='string'
    )
    
    
    :type SessionId: string
    :param SessionId: [REQUIRED]
            The unique identifier of the streaming session to be stopped.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_associated_fleets(StackName=None, NextToken=None):
    """
    Lists all fleets associated with the stack.
    See also: AWS API Documentation
    
    
    :example: response = client.list_associated_fleets(
        StackName='string',
        NextToken='string'
    )
    
    
    :type StackName: string
    :param StackName: [REQUIRED]
            The name of the stack whose associated fleets are listed.
            

    :type NextToken: string
    :param NextToken: The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

    :rtype: dict
    :return: {
        'Names': [
            'string',
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_associated_stacks(FleetName=None, NextToken=None):
    """
    Lists all stacks to which the specified fleet is associated.
    See also: AWS API Documentation
    
    
    :example: response = client.list_associated_stacks(
        FleetName='string',
        NextToken='string'
    )
    
    
    :type FleetName: string
    :param FleetName: [REQUIRED]
            The name of the fleet whose associated stacks are listed.
            

    :type NextToken: string
    :param NextToken: The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.

    :rtype: dict
    :return: {
        'Names': [
            'string',
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def start_fleet(Name=None):
    """
    Starts a fleet.
    See also: AWS API Documentation
    
    
    :example: response = client.start_fleet(
        Name='string'
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            The name of the fleet to start.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def stop_fleet(Name=None):
    """
    Stops a fleet.
    See also: AWS API Documentation
    
    
    :example: response = client.stop_fleet(
        Name='string'
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]
            The name of the fleet to stop.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def update_fleet(ImageName=None, Name=None, InstanceType=None, ComputeCapacity=None, VpcConfig=None, MaxUserDurationInSeconds=None, DisconnectTimeoutInSeconds=None, DeleteVpcConfig=None, Description=None, DisplayName=None, EnableDefaultInternetAccess=None):
    """
    Updates an existing fleet. All the attributes except the fleet name can be updated in the STOPPED state. When a fleet is in the RUNNING state, only DisplayName and ComputeCapacity can be updated. A fleet cannot be updated in a status of STARTING or STOPPING .
    See also: AWS API Documentation
    
    
    :example: response = client.update_fleet(
        ImageName='string',
        Name='string',
        InstanceType='string',
        ComputeCapacity={
            'DesiredInstances': 123
        },
        VpcConfig={
            'SubnetIds': [
                'string',
            ]
        },
        MaxUserDurationInSeconds=123,
        DisconnectTimeoutInSeconds=123,
        DeleteVpcConfig=True|False,
        Description='string',
        DisplayName='string',
        EnableDefaultInternetAccess=True|False
    )
    
    
    :type ImageName: string
    :param ImageName: The image name from which a fleet is created.

    :type Name: string
    :param Name: [REQUIRED]
            The name of the fleet.
            

    :type InstanceType: string
    :param InstanceType: The instance type of compute resources for the fleet. Fleet instances are launched from this instance type.

    :type ComputeCapacity: dict
    :param ComputeCapacity: The parameters for the capacity allocated to the fleet.
            DesiredInstances (integer) -- [REQUIRED]The desired number of streaming instances.
            

    :type VpcConfig: dict
    :param VpcConfig: The VPC configuration for the fleet.
            SubnetIds (list) --The list of subnets to which a network interface is established from the fleet instance.
            (string) --
            

    :type MaxUserDurationInSeconds: integer
    :param MaxUserDurationInSeconds: The maximum time for which a streaming session can run. The input can be any numeric value in seconds between 600 and 57600.

    :type DisconnectTimeoutInSeconds: integer
    :param DisconnectTimeoutInSeconds: The time after disconnection when a session is considered to have ended. If a user who got disconnected reconnects within this timeout interval, the user is connected back to their previous session. The input can be any numeric value in seconds between 60 and 57600.

    :type DeleteVpcConfig: boolean
    :param DeleteVpcConfig: Delete the VPC association for the specified fleet.

    :type Description: string
    :param Description: The description displayed to end users on the AppStream 2.0 portal.

    :type DisplayName: string
    :param DisplayName: The name displayed to end users on the AppStream 2.0 portal.

    :type EnableDefaultInternetAccess: boolean
    :param EnableDefaultInternetAccess: Enables or disables default Internet access for the fleet.

    :rtype: dict
    :return: {
        'Fleet': {
            'Arn': 'string',
            'Name': 'string',
            'DisplayName': 'string',
            'Description': 'string',
            'ImageName': 'string',
            'InstanceType': 'string',
            'ComputeCapacityStatus': {
                'Desired': 123,
                'Running': 123,
                'InUse': 123,
                'Available': 123
            },
            'MaxUserDurationInSeconds': 123,
            'DisconnectTimeoutInSeconds': 123,
            'State': 'STARTING'|'RUNNING'|'STOPPING'|'STOPPED',
            'VpcConfig': {
                'SubnetIds': [
                    'string',
                ]
            },
            'CreatedTime': datetime(2015, 1, 1),
            'FleetErrors': [
                {
                    'ErrorCode': 'IAM_SERVICE_ROLE_MISSING_ENI_DESCRIBE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_CREATE_ACTION'|'IAM_SERVICE_ROLE_MISSING_ENI_DELETE_ACTION'|'NETWORK_INTERFACE_LIMIT_EXCEEDED'|'INTERNAL_SERVICE_ERROR'|'IAM_SERVICE_ROLE_IS_MISSING'|'SUBNET_HAS_INSUFFICIENT_IP_ADDRESSES'|'IAM_SERVICE_ROLE_MISSING_DESCRIBE_SUBNET_ACTION'|'SUBNET_NOT_FOUND'|'IMAGE_NOT_FOUND'|'INVALID_SUBNET_CONFIGURATION',
                    'ErrorMessage': 'string'
                },
            ],
            'EnableDefaultInternetAccess': True|False
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def update_stack(DisplayName=None, Description=None, Name=None, StorageConnectors=None, DeleteStorageConnectors=None):
    """
    Updates the specified fields in the stack with the specified name.
    See also: AWS API Documentation
    
    
    :example: response = client.update_stack(
        DisplayName='string',
        Description='string',
        Name='string',
        StorageConnectors=[
            {
                'ConnectorType': 'HOMEFOLDERS',
                'ResourceIdentifier': 'string'
            },
        ],
        DeleteStorageConnectors=True|False
    )
    
    
    :type DisplayName: string
    :param DisplayName: The name displayed to end users on the AppStream 2.0 portal.

    :type Description: string
    :param Description: The description displayed to end users on the AppStream 2.0 portal.

    :type Name: string
    :param Name: [REQUIRED]
            The name of the stack to update.
            

    :type StorageConnectors: list
    :param StorageConnectors: The storage connectors to be enabled for the stack.
            (dict) --Contains the parameters for a storage connector.
            ConnectorType (string) -- [REQUIRED]The type of storage connector. The possible values include: HOMEFOLDERS.
            ResourceIdentifier (string) --The ARN associated with the storage connector.
            
            

    :type DeleteStorageConnectors: boolean
    :param DeleteStorageConnectors: Remove all the storage connectors currently enabled for the stack.

    :rtype: dict
    :return: {
        'Stack': {
            'Arn': 'string',
            'Name': 'string',
            'Description': 'string',
            'DisplayName': 'string',
            'CreatedTime': datetime(2015, 1, 1),
            'StorageConnectors': [
                {
                    'ConnectorType': 'HOMEFOLDERS',
                    'ResourceIdentifier': 'string'
                },
            ],
            'StackErrors': [
                {
                    'ErrorCode': 'STORAGE_CONNECTOR_ERROR'|'INTERNAL_SERVICE_ERROR',
                    'ErrorMessage': 'string'
                },
            ]
        }
    }
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_identity_pool(IdentityPoolName=None, AllowUnauthenticatedIdentities=None, SupportedLoginProviders=None, DeveloperProviderName=None, OpenIdConnectProviderARNs=None, CognitoIdentityProviders=None, SamlProviderARNs=None):
    """
    Creates a new identity pool. The identity pool is a store of user identity information that is specific to your AWS account. The limit on identity pools is 60 per account. The keys for SupportedLoginProviders are as follows:
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.create_identity_pool(
        IdentityPoolName='string',
        AllowUnauthenticatedIdentities=True|False,
        SupportedLoginProviders={
            'string': 'string'
        },
        DeveloperProviderName='string',
        OpenIdConnectProviderARNs=[
            'string',
        ],
        CognitoIdentityProviders=[
            {
                'ProviderName': 'string',
                'ClientId': 'string',
                'ServerSideTokenCheck': True|False
            },
        ],
        SamlProviderARNs=[
            'string',
        ]
    )
    
    
    :type IdentityPoolName: string
    :param IdentityPoolName: [REQUIRED]
            A string that you provide.
            

    :type AllowUnauthenticatedIdentities: boolean
    :param AllowUnauthenticatedIdentities: [REQUIRED]
            TRUE if the identity pool supports unauthenticated logins.
            

    :type SupportedLoginProviders: dict
    :param SupportedLoginProviders: Optional key:value pairs mapping provider names to provider app IDs.
            (string) --
            (string) --
            

    :type DeveloperProviderName: string
    :param DeveloperProviderName: The 'domain' by which Cognito will refer to your users. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName , you can use letters as well as period (. ), underscore (_ ), and dash (- ).
            Once you have set a developer provider name, you cannot change it. Please take care in setting this parameter.
            

    :type OpenIdConnectProviderARNs: list
    :param OpenIdConnectProviderARNs: A list of OpendID Connect provider ARNs.
            (string) --
            

    :type CognitoIdentityProviders: list
    :param CognitoIdentityProviders: An array of Amazon Cognito Identity user pools and their client IDs.
            (dict) --A provider representing an Amazon Cognito Identity User Pool and its client ID.
            ProviderName (string) --The provider name for an Amazon Cognito Identity User Pool. For example, cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789 .
            ClientId (string) --The client ID for the Amazon Cognito Identity User Pool.
            ServerSideTokenCheck (boolean) --TRUE if server-side token validation is enabled for the identity provider s token.
            
            

    :type SamlProviderARNs: list
    :param SamlProviderARNs: An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool.
            (string) --
            

    :rtype: dict
    :return: {
        'IdentityPoolId': 'string',
        'IdentityPoolName': 'string',
        'AllowUnauthenticatedIdentities': True|False,
        'SupportedLoginProviders': {
            'string': 'string'
        },
        'DeveloperProviderName': 'string',
        'OpenIdConnectProviderARNs': [
            'string',
        ],
        'CognitoIdentityProviders': [
            {
                'ProviderName': 'string',
                'ClientId': 'string',
                'ServerSideTokenCheck': True|False
            },
        ],
        'SamlProviderARNs': [
            'string',
        ]
    }
    
    
    :returns: 
    IdentityPoolName (string) -- [REQUIRED]
    A string that you provide.
    
    AllowUnauthenticatedIdentities (boolean) -- [REQUIRED]
    TRUE if the identity pool supports unauthenticated logins.
    
    SupportedLoginProviders (dict) -- Optional key:value pairs mapping provider names to provider app IDs.
    
    (string) --
    (string) --
    
    
    
    
    DeveloperProviderName (string) -- The "domain" by which Cognito will refer to your users. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName , you can use letters as well as period (. ), underscore (_ ), and dash (- ).
    Once you have set a developer provider name, you cannot change it. Please take care in setting this parameter.
    
    OpenIdConnectProviderARNs (list) -- A list of OpendID Connect provider ARNs.
    
    (string) --
    
    
    CognitoIdentityProviders (list) -- An array of Amazon Cognito Identity user pools and their client IDs.
    
    (dict) --A provider representing an Amazon Cognito Identity User Pool and its client ID.
    
    ProviderName (string) --The provider name for an Amazon Cognito Identity User Pool. For example, cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789 .
    
    ClientId (string) --The client ID for the Amazon Cognito Identity User Pool.
    
    ServerSideTokenCheck (boolean) --TRUE if server-side token validation is enabled for the identity providers token.
    
    
    
    
    
    SamlProviderARNs (list) -- An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool.
    
    (string) --
    
    
    
    """
    pass

def delete_identities(IdentityIdsToDelete=None):
    """
    Deletes identities from an identity pool. You can specify a list of 1-60 identities that you want to delete.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_identities(
        IdentityIdsToDelete=[
            'string',
        ]
    )
    
    
    :type IdentityIdsToDelete: list
    :param IdentityIdsToDelete: [REQUIRED]
            A list of 1-60 identities that you want to delete.
            (string) --
            

    :rtype: dict
    :return: {
        'UnprocessedIdentityIds': [
            {
                'IdentityId': 'string',
                'ErrorCode': 'AccessDenied'|'InternalServerError'
            },
        ]
    }
    
    
    """
    pass

def delete_identity_pool(IdentityPoolId=None):
    """
    Deletes a user pool. Once a pool is deleted, users will not be able to authenticate with the pool.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_identity_pool(
        IdentityPoolId='string'
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    """
    pass

def describe_identity(IdentityId=None):
    """
    Returns metadata related to the given identity, including when the identity was created and any associated linked logins.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_identity(
        IdentityId='string'
    )
    
    
    :type IdentityId: string
    :param IdentityId: [REQUIRED]
            A unique identifier in the format REGION:GUID.
            

    :rtype: dict
    :return: {
        'IdentityId': 'string',
        'Logins': [
            'string',
        ],
        'CreationDate': datetime(2015, 1, 1),
        'LastModifiedDate': datetime(2015, 1, 1)
    }
    
    
    """
    pass

def describe_identity_pool(IdentityPoolId=None):
    """
    Gets details about a particular identity pool, including the pool name, ID description, creation date, and current number of users.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_identity_pool(
        IdentityPoolId='string'
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :rtype: dict
    :return: {
        'IdentityPoolId': 'string',
        'IdentityPoolName': 'string',
        'AllowUnauthenticatedIdentities': True|False,
        'SupportedLoginProviders': {
            'string': 'string'
        },
        'DeveloperProviderName': 'string',
        'OpenIdConnectProviderARNs': [
            'string',
        ],
        'CognitoIdentityProviders': [
            {
                'ProviderName': 'string',
                'ClientId': 'string',
                'ServerSideTokenCheck': True|False
            },
        ],
        'SamlProviderARNs': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_credentials_for_identity(IdentityId=None, Logins=None, CustomRoleArn=None):
    """
    Returns credentials for the provided identity ID. Any provided logins will be validated against supported login providers. If the token is for cognito-identity.amazonaws.com, it will be passed through to AWS Security Token Service with the appropriate role for the token.
    This is a public API. You do not need any credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.get_credentials_for_identity(
        IdentityId='string',
        Logins={
            'string': 'string'
        },
        CustomRoleArn='string'
    )
    
    
    :type IdentityId: string
    :param IdentityId: [REQUIRED]
            A unique identifier in the format REGION:GUID.
            

    :type Logins: dict
    :param Logins: A set of optional name-value pairs that map provider names to provider tokens.
            (string) --
            (string) --
            

    :type CustomRoleArn: string
    :param CustomRoleArn: The Amazon Resource Name (ARN) of the role to be assumed when multiple roles were received in the token from the identity provider. For example, a SAML-based identity provider. This parameter is optional for identity providers that do not support role customization.

    :rtype: dict
    :return: {
        'IdentityId': 'string',
        'Credentials': {
            'AccessKeyId': 'string',
            'SecretKey': 'string',
            'SessionToken': 'string',
            'Expiration': datetime(2015, 1, 1)
        }
    }
    
    
    """
    pass

def get_id(AccountId=None, IdentityPoolId=None, Logins=None):
    """
    Generates (or retrieves) a Cognito ID. Supplying multiple logins will create an implicit linked account.
    This is a public API. You do not need any credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.get_id(
        AccountId='string',
        IdentityPoolId='string',
        Logins={
            'string': 'string'
        }
    )
    
    
    :type AccountId: string
    :param AccountId: A standard AWS account ID (9+ digits).

    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type Logins: dict
    :param Logins: A set of optional name-value pairs that map provider names to provider tokens. The available provider names for Logins are as follows:
            Facebook: graph.facebook.com
            Amazon Cognito Identity Provider: cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789
            Google: accounts.google.com
            Amazon: www.amazon.com
            Twitter: api.twitter.com
            Digits: www.digits.com
            (string) --
            (string) --
            

    :rtype: dict
    :return: {
        'IdentityId': 'string'
    }
    
    
    """
    pass

def get_identity_pool_roles(IdentityPoolId=None):
    """
    Gets the roles for an identity pool.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.get_identity_pool_roles(
        IdentityPoolId='string'
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :rtype: dict
    :return: {
        'IdentityPoolId': 'string',
        'Roles': {
            'string': 'string'
        },
        'RoleMappings': {
            'string': {
                'Type': 'Token'|'Rules',
                'AmbiguousRoleResolution': 'AuthenticatedRole'|'Deny',
                'RulesConfiguration': {
                    'Rules': [
                        {
                            'Claim': 'string',
                            'MatchType': 'Equals'|'Contains'|'StartsWith'|'NotEqual',
                            'Value': 'string',
                            'RoleARN': 'string'
                        },
                    ]
                }
            }
        }
    }
    
    
    """
    pass

def get_open_id_token(IdentityId=None, Logins=None):
    """
    Gets an OpenID token, using a known Cognito ID. This known Cognito ID is returned by  GetId . You can optionally add additional logins for the identity. Supplying multiple logins creates an implicit link.
    The OpenId token is valid for 15 minutes.
    This is a public API. You do not need any credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.get_open_id_token(
        IdentityId='string',
        Logins={
            'string': 'string'
        }
    )
    
    
    :type IdentityId: string
    :param IdentityId: [REQUIRED]
            A unique identifier in the format REGION:GUID.
            

    :type Logins: dict
    :param Logins: A set of optional name-value pairs that map provider names to provider tokens. When using graph.facebook.com and www.amazon.com, supply the access_token returned from the provider's authflow. For accounts.google.com, an Amazon Cognito Identity Provider, or any other OpenId Connect provider, always include the id_token .
            (string) --
            (string) --
            

    :rtype: dict
    :return: {
        'IdentityId': 'string',
        'Token': 'string'
    }
    
    
    """
    pass

def get_open_id_token_for_developer_identity(IdentityPoolId=None, IdentityId=None, Logins=None, TokenDuration=None):
    """
    Registers (or retrieves) a Cognito IdentityId and an OpenID Connect token for a user authenticated by your backend authentication process. Supplying multiple logins will create an implicit linked account. You can only specify one developer provider as part of the Logins map, which is linked to the identity pool. The developer provider is the "domain" by which Cognito will refer to your users.
    You can use GetOpenIdTokenForDeveloperIdentity to create a new identity and to link new logins (that is, user credentials issued by a public provider or developer provider) to an existing identity. When you want to create a new identity, the IdentityId should be null. When you want to associate a new login with an existing authenticated/unauthenticated identity, you can do so by providing the existing IdentityId . This API will create the identity in the specified IdentityPoolId .
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.get_open_id_token_for_developer_identity(
        IdentityPoolId='string',
        IdentityId='string',
        Logins={
            'string': 'string'
        },
        TokenDuration=123
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type IdentityId: string
    :param IdentityId: A unique identifier in the format REGION:GUID.

    :type Logins: dict
    :param Logins: [REQUIRED]
            A set of optional name-value pairs that map provider names to provider tokens. Each name-value pair represents a user from a public provider or developer provider. If the user is from a developer provider, the name-value pair will follow the syntax 'developer_provider_name': 'developer_user_identifier' . The developer provider is the 'domain' by which Cognito will refer to your users; you provided this domain while creating/updating the identity pool. The developer user identifier is an identifier from your backend that uniquely identifies a user. When you create an identity pool, you can specify the supported logins.
            (string) --
            (string) --
            

    :type TokenDuration: integer
    :param TokenDuration: The expiration time of the token, in seconds. You can specify a custom expiration time for the token so that you can cache it. If you don't provide an expiration time, the token is valid for 15 minutes. You can exchange the token with Amazon STS for temporary AWS credentials, which are valid for a maximum of one hour. The maximum token duration you can set is 24 hours. You should take care in setting the expiration time for a token, as there are significant security implications: an attacker could use a leaked token to access your AWS resources for the token's duration.

    :rtype: dict
    :return: {
        'IdentityId': 'string',
        'Token': 'string'
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def list_identities(IdentityPoolId=None, MaxResults=None, NextToken=None, HideDisabled=None):
    """
    Lists the identities in a pool.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.list_identities(
        IdentityPoolId='string',
        MaxResults=123,
        NextToken='string',
        HideDisabled=True|False
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type MaxResults: integer
    :param MaxResults: [REQUIRED]
            The maximum number of identities to return.
            

    :type NextToken: string
    :param NextToken: A pagination token.

    :type HideDisabled: boolean
    :param HideDisabled: An optional boolean parameter that allows you to hide disabled identities. If omitted, the ListIdentities API will include disabled identities in the response.

    :rtype: dict
    :return: {
        'IdentityPoolId': 'string',
        'Identities': [
            {
                'IdentityId': 'string',
                'Logins': [
                    'string',
                ],
                'CreationDate': datetime(2015, 1, 1),
                'LastModifiedDate': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_identity_pools(MaxResults=None, NextToken=None):
    """
    Lists all of the Cognito identity pools registered for your account.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.list_identity_pools(
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: [REQUIRED]
            The maximum number of identities to return.
            

    :type NextToken: string
    :param NextToken: A pagination token.

    :rtype: dict
    :return: {
        'IdentityPools': [
            {
                'IdentityPoolId': 'string',
                'IdentityPoolName': 'string'
            },
        ],
        'NextToken': 'string'
    }
    
    
    """
    pass

def lookup_developer_identity(IdentityPoolId=None, IdentityId=None, DeveloperUserIdentifier=None, MaxResults=None, NextToken=None):
    """
    Retrieves the IdentityID associated with a DeveloperUserIdentifier or the list of DeveloperUserIdentifier s associated with an IdentityId for an existing identity. Either IdentityID or DeveloperUserIdentifier must not be null. If you supply only one of these values, the other value will be searched in the database and returned as a part of the response. If you supply both, DeveloperUserIdentifier will be matched against IdentityID . If the values are verified against the database, the response returns both values and is the same as the request. Otherwise a ResourceConflictException is thrown.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.lookup_developer_identity(
        IdentityPoolId='string',
        IdentityId='string',
        DeveloperUserIdentifier='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type IdentityId: string
    :param IdentityId: A unique identifier in the format REGION:GUID.

    :type DeveloperUserIdentifier: string
    :param DeveloperUserIdentifier: A unique ID used by your backend authentication process to identify a user. Typically, a developer identity provider would issue many developer user identifiers, in keeping with the number of users.

    :type MaxResults: integer
    :param MaxResults: The maximum number of identities to return.

    :type NextToken: string
    :param NextToken: A pagination token. The first call you make will have NextToken set to null. After that the service will return NextToken values as needed. For example, let's say you make a request with MaxResults set to 10, and there are 20 matches in the database. The service will return a pagination token as a part of the response. This token can be used to call the API again and get results starting from the 11th match.

    :rtype: dict
    :return: {
        'IdentityId': 'string',
        'DeveloperUserIdentifierList': [
            'string',
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def merge_developer_identities(SourceUserIdentifier=None, DestinationUserIdentifier=None, DeveloperProviderName=None, IdentityPoolId=None):
    """
    Merges two users having different IdentityId s, existing in the same identity pool, and identified by the same developer provider. You can use this action to request that discrete users be merged and identified as a single user in the Cognito environment. Cognito associates the given source user (SourceUserIdentifier ) with the IdentityId of the DestinationUserIdentifier . Only developer-authenticated users can be merged. If the users to be merged are associated with the same public provider, but as two different users, an exception will be thrown.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.merge_developer_identities(
        SourceUserIdentifier='string',
        DestinationUserIdentifier='string',
        DeveloperProviderName='string',
        IdentityPoolId='string'
    )
    
    
    :type SourceUserIdentifier: string
    :param SourceUserIdentifier: [REQUIRED]
            User identifier for the source user. The value should be a DeveloperUserIdentifier .
            

    :type DestinationUserIdentifier: string
    :param DestinationUserIdentifier: [REQUIRED]
            User identifier for the destination user. The value should be a DeveloperUserIdentifier .
            

    :type DeveloperProviderName: string
    :param DeveloperProviderName: [REQUIRED]
            The 'domain' by which Cognito will refer to your users. This is a (pseudo) domain name that you provide while creating an identity pool. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName , you can use letters as well as period (.), underscore (_), and dash (-).
            

    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :rtype: dict
    :return: {
        'IdentityId': 'string'
    }
    
    
    """
    pass

def set_identity_pool_roles(IdentityPoolId=None, Roles=None, RoleMappings=None):
    """
    Sets the roles for an identity pool. These roles are used when making calls to  GetCredentialsForIdentity action.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.set_identity_pool_roles(
        IdentityPoolId='string',
        Roles={
            'string': 'string'
        },
        RoleMappings={
            'string': {
                'Type': 'Token'|'Rules',
                'AmbiguousRoleResolution': 'AuthenticatedRole'|'Deny',
                'RulesConfiguration': {
                    'Rules': [
                        {
                            'Claim': 'string',
                            'MatchType': 'Equals'|'Contains'|'StartsWith'|'NotEqual',
                            'Value': 'string',
                            'RoleARN': 'string'
                        },
                    ]
                }
            }
        }
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type Roles: dict
    :param Roles: [REQUIRED]
            The map of roles associated with this pool. For a given role, the key will be either 'authenticated' or 'unauthenticated' and the value will be the Role ARN.
            (string) --
            (string) --
            

    :type RoleMappings: dict
    :param RoleMappings: How users for a specific identity provider are to mapped to roles. This is a string to RoleMapping object map. The string identifies the identity provider, for example, 'graph.facebook.com' or 'cognito-idp-east-1.amazonaws.com/us-east-1_abcdefghi:app_client_id'.
            Up to 25 rules can be specified per identity provider.
            (string) --
            (dict) --A role mapping.
            Type (string) -- [REQUIRED]The role mapping type. Token will use cognito:roles and cognito:preferred_role claims from the Cognito identity provider token to map groups to roles. Rules will attempt to match claims from the token to map to a role.
            AmbiguousRoleResolution (string) --If you specify Token or Rules as the Type , AmbiguousRoleResolution is required.
            Specifies the action to be taken if either no rules match the claim value for the Rules type, or there is no cognito:preferred_role claim and there are multiple cognito:roles matches for the Token type.
            RulesConfiguration (dict) --The rules to be used for mapping users to roles.
            If you specify Rules as the role mapping type, RulesConfiguration is required.
            Rules (list) -- [REQUIRED]An array of rules. You can specify up to 25 rules per identity provider.
            Rules are evaluated in order. The first one to match specifies the role.
            (dict) --A rule that maps a claim name, a claim value, and a match type to a role ARN.
            Claim (string) -- [REQUIRED]The claim name that must be present in the token, for example, 'isAdmin' or 'paid'.
            MatchType (string) -- [REQUIRED]The match condition that specifies how closely the claim value in the IdP token must match Value .
            Value (string) -- [REQUIRED]A brief string that the claim must match, for example, 'paid' or 'yes'.
            RoleARN (string) -- [REQUIRED]The role ARN.
            
            
            
            

    """
    pass

def unlink_developer_identity(IdentityId=None, IdentityPoolId=None, DeveloperProviderName=None, DeveloperUserIdentifier=None):
    """
    Unlinks a DeveloperUserIdentifier from an existing identity. Unlinked developer users will be considered new identities next time they are seen. If, for a given Cognito identity, you remove all federated identities as well as the developer user identifier, the Cognito identity becomes inaccessible.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.unlink_developer_identity(
        IdentityId='string',
        IdentityPoolId='string',
        DeveloperProviderName='string',
        DeveloperUserIdentifier='string'
    )
    
    
    :type IdentityId: string
    :param IdentityId: [REQUIRED]
            A unique identifier in the format REGION:GUID.
            

    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type DeveloperProviderName: string
    :param DeveloperProviderName: [REQUIRED]
            The 'domain' by which Cognito will refer to your users.
            

    :type DeveloperUserIdentifier: string
    :param DeveloperUserIdentifier: [REQUIRED]
            A unique ID used by your backend authentication process to identify a user.
            

    """
    pass

def unlink_identity(IdentityId=None, Logins=None, LoginsToRemove=None):
    """
    Unlinks a federated identity from an existing account. Unlinked logins will be considered new identities next time they are seen. Removing the last linked login will make this identity inaccessible.
    This is a public API. You do not need any credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.unlink_identity(
        IdentityId='string',
        Logins={
            'string': 'string'
        },
        LoginsToRemove=[
            'string',
        ]
    )
    
    
    :type IdentityId: string
    :param IdentityId: [REQUIRED]
            A unique identifier in the format REGION:GUID.
            

    :type Logins: dict
    :param Logins: [REQUIRED]
            A set of optional name-value pairs that map provider names to provider tokens.
            (string) --
            (string) --
            

    :type LoginsToRemove: list
    :param LoginsToRemove: [REQUIRED]
            Provider names to unlink from this identity.
            (string) --
            

    """
    pass

def update_identity_pool(IdentityPoolId=None, IdentityPoolName=None, AllowUnauthenticatedIdentities=None, SupportedLoginProviders=None, DeveloperProviderName=None, OpenIdConnectProviderARNs=None, CognitoIdentityProviders=None, SamlProviderARNs=None):
    """
    Updates a user pool.
    You must use AWS Developer credentials to call this API.
    See also: AWS API Documentation
    
    
    :example: response = client.update_identity_pool(
        IdentityPoolId='string',
        IdentityPoolName='string',
        AllowUnauthenticatedIdentities=True|False,
        SupportedLoginProviders={
            'string': 'string'
        },
        DeveloperProviderName='string',
        OpenIdConnectProviderARNs=[
            'string',
        ],
        CognitoIdentityProviders=[
            {
                'ProviderName': 'string',
                'ClientId': 'string',
                'ServerSideTokenCheck': True|False
            },
        ],
        SamlProviderARNs=[
            'string',
        ]
    )
    
    
    :type IdentityPoolId: string
    :param IdentityPoolId: [REQUIRED]
            An identity pool ID in the format REGION:GUID.
            

    :type IdentityPoolName: string
    :param IdentityPoolName: [REQUIRED]
            A string that you provide.
            

    :type AllowUnauthenticatedIdentities: boolean
    :param AllowUnauthenticatedIdentities: [REQUIRED]
            TRUE if the identity pool supports unauthenticated logins.
            

    :type SupportedLoginProviders: dict
    :param SupportedLoginProviders: Optional key:value pairs mapping provider names to provider app IDs.
            (string) --
            (string) --
            

    :type DeveloperProviderName: string
    :param DeveloperProviderName: The 'domain' by which Cognito will refer to your users.

    :type OpenIdConnectProviderARNs: list
    :param OpenIdConnectProviderARNs: A list of OpendID Connect provider ARNs.
            (string) --
            

    :type CognitoIdentityProviders: list
    :param CognitoIdentityProviders: A list representing an Amazon Cognito Identity User Pool and its client ID.
            (dict) --A provider representing an Amazon Cognito Identity User Pool and its client ID.
            ProviderName (string) --The provider name for an Amazon Cognito Identity User Pool. For example, cognito-idp.us-east-1.amazonaws.com/us-east-1_123456789 .
            ClientId (string) --The client ID for the Amazon Cognito Identity User Pool.
            ServerSideTokenCheck (boolean) --TRUE if server-side token validation is enabled for the identity provider s token.
            
            

    :type SamlProviderARNs: list
    :param SamlProviderARNs: An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool.
            (string) --
            

    :rtype: dict
    :return: {
        'IdentityPoolId': 'string',
        'IdentityPoolName': 'string',
        'AllowUnauthenticatedIdentities': True|False,
        'SupportedLoginProviders': {
            'string': 'string'
        },
        'DeveloperProviderName': 'string',
        'OpenIdConnectProviderARNs': [
            'string',
        ],
        'CognitoIdentityProviders': [
            {
                'ProviderName': 'string',
                'ClientId': 'string',
                'ServerSideTokenCheck': True|False
            },
        ],
        'SamlProviderARNs': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_tags_to_certificate(CertificateArn=None, Tags=None):
    """
    Adds one or more tags to an ACM Certificate. Tags are labels that you can use to identify and organize your AWS resources. Each tag consists of a key and an optional value . You specify the certificate on input by its Amazon Resource Name (ARN). You specify the tag by using a key-value pair.
    You can apply a tag to just one certificate if you want to identify a specific characteristic of that certificate, or you can apply the same tag to multiple certificates if you want to filter for a common relationship among those certificates. Similarly, you can apply the same tag to multiple resources if you want to specify a relationship among those resources. For example, you can add the same tag to an ACM Certificate and an Elastic Load Balancing load balancer to indicate that they are both used by the same website. For more information, see Tagging ACM Certificates .
    To remove one or more tags, use the  RemoveTagsFromCertificate action. To view all of the tags that have been applied to the certificate, use the  ListTagsForCertificate action.
    See also: AWS API Documentation
    
    
    :example: response = client.add_tags_to_certificate(
        CertificateArn='string',
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains the ARN of the ACM Certificate to which the tag is to be applied. This must be of the form:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    :type Tags: list
    :param Tags: [REQUIRED]
            The key-value pair that defines the tag. The tag value is optional.
            (dict) --A key-value pair that identifies or specifies metadata about an ACM resource.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            

    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def delete_certificate(CertificateArn=None):
    """
    Deletes an ACM Certificate and its associated private key. If this action succeeds, the certificate no longer appears in the list of ACM Certificates that can be displayed by calling the  ListCertificates action or be retrieved by calling the  GetCertificate action. The certificate will not be available for use by other AWS services.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_certificate(
        CertificateArn='string'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains the ARN of the ACM Certificate to be deleted. This must be of the form:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    """
    pass

def describe_certificate(CertificateArn=None):
    """
    Returns detailed metadata about the specified ACM Certificate.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_certificate(
        CertificateArn='string'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the ACM Certificate. The ARN must have the following form:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    :rtype: dict
    :return: {
        'Certificate': {
            'CertificateArn': 'string',
            'DomainName': 'string',
            'SubjectAlternativeNames': [
                'string',
            ],
            'DomainValidationOptions': [
                {
                    'DomainName': 'string',
                    'ValidationEmails': [
                        'string',
                    ],
                    'ValidationDomain': 'string',
                    'ValidationStatus': 'PENDING_VALIDATION'|'SUCCESS'|'FAILED'
                },
            ],
            'Serial': 'string',
            'Subject': 'string',
            'Issuer': 'string',
            'CreatedAt': datetime(2015, 1, 1),
            'IssuedAt': datetime(2015, 1, 1),
            'ImportedAt': datetime(2015, 1, 1),
            'Status': 'PENDING_VALIDATION'|'ISSUED'|'INACTIVE'|'EXPIRED'|'VALIDATION_TIMED_OUT'|'REVOKED'|'FAILED',
            'RevokedAt': datetime(2015, 1, 1),
            'RevocationReason': 'UNSPECIFIED'|'KEY_COMPROMISE'|'CA_COMPROMISE'|'AFFILIATION_CHANGED'|'SUPERCEDED'|'CESSATION_OF_OPERATION'|'CERTIFICATE_HOLD'|'REMOVE_FROM_CRL'|'PRIVILEGE_WITHDRAWN'|'A_A_COMPROMISE',
            'NotBefore': datetime(2015, 1, 1),
            'NotAfter': datetime(2015, 1, 1),
            'KeyAlgorithm': 'RSA_2048'|'RSA_1024'|'EC_prime256v1',
            'SignatureAlgorithm': 'string',
            'InUseBy': [
                'string',
            ],
            'FailureReason': 'NO_AVAILABLE_CONTACTS'|'ADDITIONAL_VERIFICATION_REQUIRED'|'DOMAIN_NOT_ALLOWED'|'INVALID_PUBLIC_DOMAIN'|'OTHER',
            'Type': 'IMPORTED'|'AMAZON_ISSUED',
            'RenewalSummary': {
                'RenewalStatus': 'PENDING_AUTO_RENEWAL'|'PENDING_VALIDATION'|'SUCCESS'|'FAILED',
                'DomainValidationOptions': [
                    {
                        'DomainName': 'string',
                        'ValidationEmails': [
                            'string',
                        ],
                        'ValidationDomain': 'string',
                        'ValidationStatus': 'PENDING_VALIDATION'|'SUCCESS'|'FAILED'
                    },
                ]
            }
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_certificate(CertificateArn=None):
    """
    Retrieves an ACM Certificate and certificate chain for the certificate specified by an ARN. The chain is an ordered list of certificates that contains the root certificate, intermediate certificates of subordinate CAs, and the ACM Certificate. The certificate and certificate chain are base64 encoded. If you want to decode the certificate chain to see the individual certificate fields, you can use OpenSSL.
    See also: AWS API Documentation
    
    
    :example: response = client.get_certificate(
        CertificateArn='string'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains a certificate ARN in the following format:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    :rtype: dict
    :return: {
        'Certificate': 'string',
        'CertificateChain': 'string'
    }
    
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def import_certificate(CertificateArn=None, Certificate=None, PrivateKey=None, CertificateChain=None):
    """
    Imports an SSL/TLS certificate into AWS Certificate Manager (ACM) to use with ACM's integrated AWS services .
    For more information about importing certificates into ACM, including the differences between certificates that you import and those that ACM provides, see Importing Certificates in the AWS Certificate Manager User Guide .
    To import a certificate, you must provide the certificate and the matching private key. When the certificate is not self-signed, you must also provide a certificate chain. You can omit the certificate chain when importing a self-signed certificate.
    The certificate, private key, and certificate chain must be PEM-encoded. For more information about converting these items to PEM format, see Importing Certificates Troubleshooting in the AWS Certificate Manager User Guide .
    To import a new certificate, omit the CertificateArn field. Include this field only when you want to replace a previously imported certificate.
    This operation returns the Amazon Resource Name (ARN) of the imported certificate.
    See also: AWS API Documentation
    
    
    :example: response = client.import_certificate(
        CertificateArn='string',
        Certificate=b'bytes',
        PrivateKey=b'bytes',
        CertificateChain=b'bytes'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: The Amazon Resource Name (ARN) of an imported certificate to replace. To import a new certificate, omit this field.

    :type Certificate: bytes
    :param Certificate: [REQUIRED]
            The certificate to import. It must meet the following requirements:
            Must be PEM-encoded.
            Must contain a 1024-bit or 2048-bit RSA public key.
            Must be valid at the time of import. You cannot import a certificate before its validity period begins (the certificate's NotBefore date) or after it expires (the certificate's NotAfter date).
            

    :type PrivateKey: bytes
    :param PrivateKey: [REQUIRED]
            The private key that matches the public key in the certificate. It must meet the following requirements:
            Must be PEM-encoded.
            Must be unencrypted. You cannot import a private key that is protected by a password or passphrase.
            

    :type CertificateChain: bytes
    :param CertificateChain: The certificate chain. It must be PEM-encoded.

    :rtype: dict
    :return: {
        'CertificateArn': 'string'
    }
    
    
    """
    pass

def list_certificates(CertificateStatuses=None, NextToken=None, MaxItems=None):
    """
    Retrieves a list of ACM Certificates and the domain name for each. You can optionally filter the list to return only the certificates that match the specified status.
    See also: AWS API Documentation
    
    
    :example: response = client.list_certificates(
        CertificateStatuses=[
            'PENDING_VALIDATION'|'ISSUED'|'INACTIVE'|'EXPIRED'|'VALIDATION_TIMED_OUT'|'REVOKED'|'FAILED',
        ],
        NextToken='string',
        MaxItems=123
    )
    
    
    :type CertificateStatuses: list
    :param CertificateStatuses: The status or statuses on which to filter the list of ACM Certificates.
            (string) --
            

    :type NextToken: string
    :param NextToken: Use this parameter only when paginating results and only in a subsequent request after you receive a response with truncated results. Set it to the value of NextToken from the response you just received.

    :type MaxItems: integer
    :param MaxItems: Use this parameter when paginating results to specify the maximum number of items to return in the response. If additional items exist beyond the number you specify, the NextToken element is sent in the response. Use this NextToken value in a subsequent request to retrieve additional items.

    :rtype: dict
    :return: {
        'NextToken': 'string',
        'CertificateSummaryList': [
            {
                'CertificateArn': 'string',
                'DomainName': 'string'
            },
        ]
    }
    
    
    """
    pass

def list_tags_for_certificate(CertificateArn=None):
    """
    Lists the tags that have been applied to the ACM Certificate. Use the certificate's Amazon Resource Name (ARN) to specify the certificate. To add a tag to an ACM Certificate, use the  AddTagsToCertificate action. To delete a tag, use the  RemoveTagsFromCertificate action.
    See also: AWS API Documentation
    
    
    :example: response = client.list_tags_for_certificate(
        CertificateArn='string'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains the ARN of the ACM Certificate for which you want to list the tags. This has the following form:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    :rtype: dict
    :return: {
        'Tags': [
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    }
    
    
    """
    pass

def remove_tags_from_certificate(CertificateArn=None, Tags=None):
    """
    Remove one or more tags from an ACM Certificate. A tag consists of a key-value pair. If you do not specify the value portion of the tag when calling this function, the tag will be removed regardless of value. If you specify a value, the tag is removed only if it is associated with the specified value.
    To add tags to a certificate, use the  AddTagsToCertificate action. To view all of the tags that have been applied to a specific ACM Certificate, use the  ListTagsForCertificate action.
    See also: AWS API Documentation
    
    
    :example: response = client.remove_tags_from_certificate(
        CertificateArn='string',
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains the ARN of the ACM Certificate with one or more tags that you want to remove. This must be of the form:
            arn:aws:acm:region:123456789012:certificate/12345678-1234-1234-1234-123456789012
            For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces .
            

    :type Tags: list
    :param Tags: [REQUIRED]
            The key-value pair that defines the tag to remove.
            (dict) --A key-value pair that identifies or specifies metadata about an ACM resource.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            

    """
    pass

def request_certificate(DomainName=None, SubjectAlternativeNames=None, IdempotencyToken=None, DomainValidationOptions=None):
    """
    Requests an ACM Certificate for use with other AWS services. To request an ACM Certificate, you must specify the fully qualified domain name (FQDN) for your site. You can also specify additional FQDNs if users can reach your site by using other names. For each domain name you specify, email is sent to the domain owner to request approval to issue the certificate. After receiving approval from the domain owner, the ACM Certificate is issued. For more information, see the AWS Certificate Manager User Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.request_certificate(
        DomainName='string',
        SubjectAlternativeNames=[
            'string',
        ],
        IdempotencyToken='string',
        DomainValidationOptions=[
            {
                'DomainName': 'string',
                'ValidationDomain': 'string'
            },
        ]
    )
    
    
    :type DomainName: string
    :param DomainName: [REQUIRED]
            Fully qualified domain name (FQDN), such as www.example.com, of the site that you want to secure with an ACM Certificate. Use an asterisk (*) to create a wildcard certificate that protects several sites in the same domain. For example, *.example.com protects www.example.com, site.example.com, and images.example.com.
            

    :type SubjectAlternativeNames: list
    :param SubjectAlternativeNames: Additional FQDNs to be included in the Subject Alternative Name extension of the ACM Certificate. For example, add the name www.example.net to a certificate for which the DomainName field is www.example.com if users can reach your site by using either name.
            (string) --
            

    :type IdempotencyToken: string
    :param IdempotencyToken: Customer chosen string that can be used to distinguish between calls to RequestCertificate . Idempotency tokens time out after one hour. Therefore, if you call RequestCertificate multiple times with the same idempotency token within one hour, ACM recognizes that you are requesting only one certificate and will issue only one. If you change the idempotency token for each call, ACM recognizes that you are requesting multiple certificates.

    :type DomainValidationOptions: list
    :param DomainValidationOptions: The domain name that you want ACM to use to send you emails to validate your ownership of the domain.
            (dict) --Contains information about the domain names that you want ACM to use to send you emails to validate your ownership of the domain.
            DomainName (string) -- [REQUIRED]A fully qualified domain name (FQDN) in the certificate request.
            ValidationDomain (string) -- [REQUIRED]The domain name that you want ACM to use to send you validation emails. This domain name is the suffix of the email addresses that you want ACM to use. This must be the same as the DomainName value or a superdomain of the DomainName value. For example, if you request a certificate for testing.example.com , you can specify example.com for this value. In that case, ACM sends domain validation emails to the following five addresses:
            admin@example.com
            administrator@example.com
            hostmaster@example.com
            postmaster@example.com
            webmaster@example.com
            
            

    :rtype: dict
    :return: {
        'CertificateArn': 'string'
    }
    
    
    """
    pass

def resend_validation_email(CertificateArn=None, Domain=None, ValidationDomain=None):
    """
    Resends the email that requests domain ownership validation. The domain owner or an authorized representative must approve the ACM Certificate before it can be issued. The certificate can be approved by clicking a link in the mail to navigate to the Amazon certificate approval website and then clicking I Approve . However, the validation email can be blocked by spam filters. Therefore, if you do not receive the original mail, you can request that the mail be resent within 72 hours of requesting the ACM Certificate. If more than 72 hours have elapsed since your original request or since your last attempt to resend validation mail, you must request a new certificate.
    See also: AWS API Documentation
    
    
    :example: response = client.resend_validation_email(
        CertificateArn='string',
        Domain='string',
        ValidationDomain='string'
    )
    
    
    :type CertificateArn: string
    :param CertificateArn: [REQUIRED]
            String that contains the ARN of the requested certificate. The certificate ARN is generated and returned by the RequestCertificate action as soon as the request is made. By default, using this parameter causes email to be sent to all top-level domains you specified in the certificate request.
            The ARN must be of the form:
            arn:aws:acm:us-east-1:123456789012:certificate/12345678-1234-1234-1234-123456789012
            

    :type Domain: string
    :param Domain: [REQUIRED]
            The fully qualified domain name (FQDN) of the certificate that needs to be validated.
            

    :type ValidationDomain: string
    :param ValidationDomain: [REQUIRED]
            The base validation domain that will act as the suffix of the email addresses that are used to send the emails. This must be the same as the Domain value or a superdomain of the Domain value. For example, if you requested a certificate for site.subdomain.example.com and specify a ValidationDomain of subdomain.example.com , ACM sends email to the domain registrant, technical contact, and administrative contact in WHOIS and the following five addresses:
            admin@subdomain.example.com
            administrator@subdomain.example.com
            hostmaster@subdomain.example.com
            postmaster@subdomain.example.com
            webmaster@subdomain.example.com
            

    """
    pass

